NamedLocation class

Specifies code locations where metadata annotations should be attached and where they should point to in the original proto.

Constructors

NamedLocation({required String name, required List<int> fieldPathSegment, required int start})

Properties

fieldPathSegment → List<int>
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited