BaseType class

Represents the base type of a particular field in a proto definition. (Doesn't include List<> for repeated fields.)

Constructors

BaseType(FieldDescriptorProto field, FeatureSet features, GenerationContext ctx)
factory

Properties

descriptor → FieldDescriptorProto_Type
final
generator → ProtobufContainer?
final
hashCode → int
The hash code for this object.
no setterinherited
isBytes → bool
no setter
isEnum → bool
no setter
isGroup → bool
no setter
isMessage → bool
no setter
isPackable → bool
no setter
isString → bool
no setter
package → String
The package where this type is declared. (Always the empty string for primitive types.)
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setter → String?
final
typeConstantSuffix → String
The suffix of the constant for this type in PbFieldType. (For example, 'B' for boolean or '3' for int32.)
final
unprefixed → String
The name of the Dart type when in the same package.
final

Methods

getDartType(FileGenerator fileGen) → String
Returns the name to use in generated code for this Dart type.
getRepeatedDartType(FileGenerator fileGen) → String
getRepeatedDartTypeIterable(FileGenerator fileGen) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prefixed(FileGenerator fileGen) → String
The Dart expression to use for this type when in a different file.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited