EnumGenerator class

Inheritance

Constructors

EnumGenerator.nested(EnumDescriptorProto descriptor, ProtobufContainer parent, Set<String> usedClassNames, int repeatedFieldIndex)
EnumGenerator.topLevel(EnumDescriptorProto descriptor, ProtobufContainer parent, Set<String> usedClassNames, int repeatedFieldIndex)

Properties

binaryDescriptorName → String
no setterinherited
classname → String
final
dartNames → Map<String, String>
Maps the name of an enum value to the Dart name we will use for it.
final
dottedName → String
The fully qualified name with a leading '.'.
no setterinherited
features → FeatureSet
final
fieldPath → List<int>
The field path contains the field IDs and indices (for repeated fields) that lead to the proto member corresponding to a piece of generated code. Repeated fields in the descriptor are further identified by the index of the message in question. For more information see https://github.com/protocolbuffers/protobuf/blob/master/src/google/protobuf/descriptor.proto#L728
latefinal
fileGen → FileGenerator?
The generator of the .pb.dart file defining this entity.
no setteroverride
fullName → String
final
hashCode → int
The hash code for this object.
no setterinherited
package → String
no setteroverride
parent → ProtobufContainer
For top-level enums: FileGenerator. For nested enums: MessageGenerator.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toplevelParent → ProtobufContainer?
The top-level parent of this entity, or itself if it is a top-level entity.
no setterinherited

Methods

generate(IndentingWriter out) → void
generateConstants(IndentingWriter out) → void
Writes a Dart constant containing the JSON for the EnumDescriptorProto.
getJsonConstant(FileGenerator context) → String
Returns a const expression that evaluates to the JSON for this message.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(GenerationContext ctx) → void
Make this enum available as a field type.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited