ExtensionGenerator class

Constructors

ExtensionGenerator.nested(FieldDescriptorProto descriptor, ProtobufContainer parent, Set<String> usedNames, int repeatedFieldIndex)
ExtensionGenerator.topLevel(FieldDescriptorProto descriptor, ProtobufContainer parent, Set<String> usedNames, int repeatedFieldIndex)

Properties

features → FeatureSet
no setter
fieldPath → List<int>
See ProtobufContainer
latefinal
fileGen → FileGenerator?
The generator of the .pb.dart file where this extension will be defined.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setter
needsFixnumImport → bool
no setter
package → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addConstantImportsTo(Set<FileGenerator> imports) → void
For each .pb.dart file that the generated code needs to import, add its generator.
addImportsTo(Set<FileGenerator> imports, Set<FileGenerator> enumImports) → void
Adds dependencies of generate to imports.
generate(IndentingWriter out) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(GenerationContext ctx) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited