ServiceGenerator class

Constructors

ServiceGenerator(ServiceDescriptorProto _descriptor, FileGenerator fileGen, Set<String> usedNames)

Properties

binaryDescriptorName → String
no setter
classname → String
final
fileGen → FileGenerator
The generator of the .pb.dart file that will contain this service.
final
hashCode → int
The hash code for this object.
no setterinherited
jsonConstant → String
no setter
messageJsonConstant → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addConstantImportsTo(Set<FileGenerator> imports) → void
Adds dependencies of generateConstants to imports.
addImportsTo(Set<FileGenerator> imports) → void
Adds dependencies of generate to imports.
generate(IndentingWriter out) → void
generateConstants(IndentingWriter out) → void
Writes Dart constants for the service and message descriptors.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(GenerationContext ctx) → void
Finds all message types used by this service.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

serviceBaseName(String originalName) → String